package net.sergeych.merge3

/**
 * Check that other is inside this (inclusive)
 */
operator fun <T: Comparable<T>>ClosedRange<T>.contains(other: ClosedRange<T>): Boolean =
    other.start >= start && other.endInclusive <= endInclusive


/**
 * Check that [other] overlaps (e.g., other has non-empty intersection with this), this also
 * includes the case when other is inside this or this is inside other completely. Use [contains] to exclude
 * the containing.
 */

infix fun <T: Comparable<T>>ClosedRange<T>.overlaps(other: ClosedRange<T>): Boolean {
    return start in other || endInclusive in other
}